@@ -38,7 +38,6 @@ class LeaderboardPlayerV2(InitOptions):
 @dataclass
 class LeaderboardV2(InitOptions):
     last_update: int
-    last_update_raw: int
     next_update: int
     total_players: int
     radiant_threshold: int
@@ -48,4 +47,8 @@ class LeaderboardV2(InitOptions):
     players: List[LeaderboardPlayerV2]
 
     def __post_init__(self):
-        self.players = [LeaderboardPlayerV2(**player) for player in self.players]
+        self.players = [
+            LeaderboardPlayerV2(**player)
+            for player in self.players
+            if player is not None
+        ]
